# Esto

El Zen de Python en español.

## Instalación

```bash
pip install esto

Uso

import esto

Esto imprimirá el Zen de Python en español.

Descripción

Este módulo es una adaptación en español del famoso "Zen de Python", que originalmente fue escrito por Tim Peters. Utiliza un cifrado ROT13 para ocultar el texto y luego lo decodifica al importar el módulo.

Autor

    Autor: Alonso Palomino F. (alias @alpfa)

    Fecha de creación: Jue 13 Mar 2025 01:26:01

Licencia

Este proyecto está bajo la licencia MIT. Para más detalles, consulta el archivo LICENSE.

Contribuciones

¡Las contribuciones son bienvenidas! Si tienes alguna idea para mejorar este proyecto, no dudes en hacer un fork y enviar un pull request.

Issues

Si encuentras algún problema o tienes alguna sugerencia, por favor abre un issue.

¡Gracias por usar esto! Espero que disfrutes del Zen de Python en español.